<?php
namespace Teknisa\CUS\Modules\Relatorio\Controllers;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;

class Cus00104 extends \Zeedhi\Framework\Controller\Report {

    protected $entityManager;
    protected $servicoPorGrupo;
    protected $qr2Strategy;
    protected $crudService;
    protected $birtStrategy;

    public function __construct($reportService, $entityManager, $servicoPorGrupo, $qr2Strategy, $crudService, $birtStrategy, $util) {

        $this->entityManager    = $entityManager;
        $this->servicoPorGrupo  = $servicoPorGrupo;
        $this->qr2Strategy      = $qr2Strategy;
        $this->reportService    = $reportService;
        $this->crudService      = $crudService;
        $this->birtStrategy     = $birtStrategy;
        $this->util             = $util;
    }

    protected $reportMapping = array (
        'CUS00104' => 
        array (
        'strategy' => 'BIRT',
        'parameterMapping' => 
            array (
            'CDFILIAL'      => 'P_CDFILIAL',
            'LISTASERV'     => 'P_CDSERVFILI',
            'CDTIPOCUSTO'   => 'P_NRTIPOCUSTO',
            'NMTIPOCUSTO'   => 'P_NMCUSTO',
            'DTINICIAL'     => 'P_DTINICIAL',
            'DTFINAL'       => 'P_DTFINAL',
            'LISTADIETA'    => 'P_CDDIETPAD',
            'TCDIETPAD'     => 'P_TCDDIETPAD',
            'IDCOMCUSPERC'  => 'P_IDCOMCUSPERC',
            'NRORG'         => 'P_NRORG' 
            ),
        ),
        'CUS00105' => 
        array (
        'strategy' => 'BIRT',
        'parameterMapping' => 
            array (
            'CDFILIAL'    => 'P_CDFILIAL',
            'LISTASERV'   => 'P_CDSERVFILI',
            'CDTIPOCUSTO' => 'P_NRTIPOCUSTO',
            'NMTIPOCUSTO' => 'P_NMCUSTO',
            'DTINICIAL'   => 'P_DTINICIAL',
            'DTFINAL'     => 'P_DTFINAL',
            'LISTADIETA'  => 'P_CDDIETPAD',
            'TCDIETPAD'   => 'P_TCDDIETPAD',
            'IDCOMCUSPERC'=> 'P_IDCOMCUSPERC',
            'NRORG'       => 'P_NRORG' 
            ),
        ),
    );
    
    public function getParamsFilial($filial) {
        $sql = "SELECT IDCOMCUSPERC FROM PARAMFILIAL WHERE CDFILIAL = :CDFILIAL";
        $params = array (
            "CDFILIAL" => "$filial"
        );
        
        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();
        return $result;
    }

    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
        $idComCusPerc = $this->getParamsFilial($row['CDFILIAL']);
        $row['IDCOMCUSPERC'] = $idComCusPerc[0]["IDCOMCUSPERC"];
        if($row['TCDIETPAD'] == 'T') {
            $row['LISTADIETA'] = 'T';
        }
        
        $row['NMTIPOCUSTO'] = urlencode($row['NMTIPOCUSTO']);
    
        
        $cdoperador = $row['CDOPERADOR'];
        $cdfilial = $row['CDFILIAL'];
        $nrorg = $row['NRORG'];
        $cdgrupserv = $row['LISTAGRUPSERV'];
        
        if($cdgrupserv == 'T'){
            $conditions = array();
            $gruposerv = $this->crudService->getFilteredDataSet('grupserv', $conditions)->getRows();
            $cdgrupserv = [];

            foreach ($gruposerv as $value) {
                array_push($cdgrupserv, $value["CDGRUPSERV"]);
            }

            $row["LISTAGRUPSERV"] = implode('_', $cdgrupserv);
            $cdgrupserv = $row["LISTAGRUPSERV"];
        }

        if ($row['LISTASERV'] == 'T') {
            $listaServico = $this->servicoPorGrupo->retornaServicosPorGrupo($nrorg, $cdfilial, $cdoperador, $cdgrupserv);
            $row['LISTASERV'] = $listaServico == '' ? 'N' : $listaServico;
        }
    }
}